## 转融券交易汇总

接口：slb_sec

描述：转融通转融券交易汇总

限量：单次最大可以提取5000行数据，可循环获取所有历史

积分：2000积分每分钟请求200次，5000积分500次请求

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| ts_code | str | N | 股票代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期（YYYYMMDD） |
| ts_code | str | Y | 股票代码 |
| name | str | Y | 股票名称 |
| ope_inv | float | Y | 期初余量(万股) |
| lent_qnt | float | Y | 转融券融出数量(万股) |
| cls_inv | float | Y | 期末余量(万股) |
| end_bal | float | Y | 期末余额(万元) |

接口示例

```python
pro = ts.pro_api()

df = pro.slb_sec(trade_date='20240620')
```

数据示例

```python
trade_date   ts_code   name  ope_inv lent_qnt  cls_inv   end_bal
0      20240620  000001.SZ   平安银行   186.97     1.43   188.40   2004.70
```